@@ -41,6 +41,7 @@
 #' the posterior mean network size distribution with sample histogram overlaid
 #' is produced.  If \code{"both"}, then all plots for \code{"N"} and
 #' \code{"others"} are produced.
+#' @param main an overall title for the posterior plot.
 #' @param \dots further arguments passed to or from other methods.
 #' @seealso The model fitting function \code{\link{posteriorsize}},
 #' \code{\link[graphics]{plot}}.
@@ -107,7 +108,8 @@
 #' @method plot sspse
 #' @export
 plot.sspse <- function(x,
-		       xlim=NULL,data=NULL,support=1000,HPD.level=0.90,N=NULL,ylim=NULL,mcmc=FALSE,type="both",...){
+		       xlim=NULL,data=NULL,support=1000,HPD.level=0.90,N=NULL,ylim=NULL,mcmc=FALSE,type="both",
+		       main="posterior for population size",...){
   p.args <- as.list( sys.call() )[-c(1,2)]
   formal.args<-formals(sys.function())[-c(1)]
 
@@ -118,16 +120,18 @@ plot.sspse <- function(x,
   for(arg in names(p.args)){ control[arg]<-list(get(arg)) }
 
 out <- x$sample
+# sabline <- function(v,...){graphics::segments(x0=v,...,y0=control$ylim[1],y1=control$ylim[2])}
+sabline <- function(v,...){graphics::segments(x0=v,...,y0=graphics::par("usr")[3],y1=graphics::par("usr")[4])}
 if(!is.null(out) & control$mcmc){
   mcmc.len <- min(1000, nrow(out))
   a=round(seq.int(from=1,to=nrow(out),length.out=mcmc.len))
   mcp <- attr(out,"mcpar")
   b=coda::mcmc(out[a,],start=mcp[1],end=mcp[2],thin=floor((mcp[2]-mcp[1])/mcmc.len + 1))
-  plot(b)
+  graphics::plot(b)
   return(invisible())
 }
 #suppressMessages(require(locfit,quietly=TRUE))
-#if(ask){par(ask=TRUE)}
+#if(ask){graphics::par(ask=TRUE)}
 if(is.null(out)){
   x$n <- min(x$x)
   x$lpriorm <- log(x$lprior)
@@ -141,31 +145,32 @@ if(!is.null(out)){
   outN <- out[,"N"]
   ##a=locfit( ~ lp(outN, nn=0.35, h=0, maxk=500))
   xp <- seq(x$n,x$maxN, length=control$support)
-  posdensN=bgk_kde(data=outN,n=2^(ceiling(log(x$maxN-x$n)/log(2))),MIN=x$n)
-  posdensN <- spline(x=posdensN[1,],y=posdensN[2,],xout=xp)$y
+  posdensN=bgk_kde(data=outN,n=2^(ceiling(log(x$maxN-x$n)/log(2))),MIN=x$n,MAX=x$maxN)
+  maxposdensN <- max(posdensN[1,],na.rm=TRUE)
+  posdensN <- stats::spline(x=posdensN[1,],y=posdensN[2,],xout=xp)$y
+  posdensN[xp > maxposdensN] <- 0
   #a=locfit::locfit( ~ lp(outN,nn=0.5))
   #posdensN <- predict(a, newdata=xp)
   posdensN <- control$support*posdensN / ((x$maxN-x$n)*sum(posdensN))
   #
-  if(is.null(control$xlim)){control$xlim <- quantile(outN,0.99)}
+  if(is.null(control$xlim)){control$xlim <- stats::quantile(outN,0.99)}
   if(is.null(control$ylim)){control$ylim <- c(0,max(posdensN,lpriorm))}
   if(control$type %in% c("N","both")){
-  plot(x=xp,y=posdensN,type='l', xlab="population size", 
-    main="posterior for population size",
+  outp <- graphics::plot(x=xp,y=posdensN,type='l', xlab="population size", 
   # ylim=c(0,max(posdensN,lpriorm)),
   # sub="mean prior = 1000",
-    ylab="posterior density",xlim=c(x$n,control$xlim),ylim=control$ylim)
+    ylab="posterior density",xlim=c(x$n,control$xlim),ylim=control$ylim, main=main)
   #
-  legend('topright',lty=c(1,2,1,1,1,1,1),col=c(1,1,2,3,4,5),
+  graphics::legend('topright',lty=c(1,2,1,1,2,1),col=c(1,1,2,3,4,5),
     legend=c("posterior","prior","median","mean",
              paste(round(control$HPD.level*100),"% interval",sep=""),
              "mode"),
     bty="n",cex=0.75)
-  abline(v=x$n,lty=2)
+  sabline(v=x$n,lty=2)
   #
   lpriorm <- exp(x$lpriorm-max(x$lpriorm))
   lpriorm <- lpriorm/sum(lpriorm)
-  lines(x=x$n+(1:length(lpriorm))-1,y=lpriorm,lty=2)
+  graphics::lines(x=x$n+(1:length(lpriorm))-1,y=lpriorm,lty=2)
   # Next from coda
   #hpd <- HPDinterval(x$sample[,"N"])[1:2]
   # MSH using locfit
@@ -180,55 +185,56 @@ if(!is.null(out)){
   l90 <- xp[which.max(cy>0.9)]
   l50 <- xp[which.max(cy>0.5)]
 #
-# abline(v=median(outN,na.rm=TRUE),col=2)
-# abline(v=mean(outN,na.rm=TRUE),col=3)
-  abline(v=l50,col=2)
-  abline(v=mp,col=3)
-  abline(v=c(x$n,x$maxN),lty=2)
-  if(!is.null(control$N)){abline(v=control$N,lty=1,col=1)}
-  abline(v=hpd,lty=2,col=4)
+# sabline(v=stats::median(outN,na.rm=TRUE),col=2)
+# sabline(v=mean(outN,na.rm=TRUE),col=3)
+  sabline(v=mp,col=3)
+  sabline(v=l50,col=2)
+  sabline(v=map,col=5)
+  sabline(v=c(x$n,x$maxN),lty=2)
+  if(!is.null(control$N)){sabline(v=control$N,lty=1,col=1)}
+  sabline(v=hpd,lty=2,col=4)
   yloc <- control$ylim[2]*0.06
-  par(xpd=NA)
-  text(x=hpd[1],y=-yloc,col=4,cex=0.5,labels=paste(round(hpd[1])))
-  text(x=hpd[2],y=-yloc,col=4,cex=0.5,labels=paste(round(hpd[2])))
-  text(x=x$n,y=-0,labels=paste(x$n),col=1,cex=1.0)
-  text(x=round(mp),y=-yloc,col=3,cex=0.5,labels=paste(round(mp)))
-  text(x=l50,y=-yloc,col=2,cex=0.5,labels=paste(round(l50)))
-  text(x=map,y=-yloc,col=5,cex=0.5,labels=paste(round(map)))
-  if(!is.null(control$N)){text(x=control$N,y=-yloc,col=1,cex=0.5,labels="truth")}
+  graphics::par(xpd=NA)
+  graphics::text(x=hpd[1],y=-yloc,col=4,cex=0.5,labels=paste(round(hpd[1])))
+  graphics::text(x=hpd[2],y=-yloc,col=4,cex=0.5,labels=paste(round(hpd[2])))
+  graphics::text(x=x$n,y=-0,labels=paste(x$n),col=1,cex=1.0)
+  graphics::text(x=round(mp),y=-yloc,col=3,cex=0.5,labels=paste(round(mp)))
+  graphics::text(x=l50,y=-yloc,col=2,cex=0.5,labels=paste(round(l50)))
+  graphics::text(x=map,y=-yloc,col=5,cex=0.5,labels=paste(round(map)))
+  if(!is.null(control$N)){graphics::text(x=control$N,y=-yloc,col=1,cex=0.5,labels="truth")}
 #
 #cat(sprintf("Prior:\nMean = %d, Median = %d, Mode = %d, 25%% = %d, 75%% = %d.\n",
 # round(x$mean.prior.size), round(x$median.prior.size), round(x$mode.prior.size), round(x$quartiles.prior.size[1]), round(x$quartiles.prior.size[2])))
 #cat(sprintf("Posterior:\nMean = %d, Median = %d, MAP = %d, 90%% = %d, HPD = (%d, %d).\n",
 # round(mp),round(l50),round(map),round(l90),round(hpd[1]),round(hpd[2])))
 #
-lines(x=x$n+(1:length(lpriorm))-1,y=lpriorm,lty=2)
+  graphics::lines(x=x$n+(1:length(lpriorm))-1,y=lpriorm,lty=2)
 }
 #
 if(control$type %in% c("others","both")){
-out[is.na(out)] <- apply(out,2,median,na.rm=TRUE)
+out[is.na(out)] <- apply(out,2,stats::median,na.rm=TRUE)
 if("mu" %in% colnames(out)){
- plot(density(out[,"mu"],na.rm=TRUE), xlab="mean network size", main="posterior for mean network size in the population")
- plot(density(out[,"sigma"],na.rm=TRUE), xlab="s.d. network size", main="posterior for s.d. of the network size")
+ graphics::plot(stats::density(out[,"mu"],na.rm=TRUE), xlab="mean network size", main="posterior for mean network size in the population")
+ graphics::plot(stats::density(out[,"sigma"],na.rm=TRUE), xlab="s.d. network size", main="posterior for s.d. of the network size")
 }
 if("mu0" %in% colnames(out)){
- plot(density(out[,"mu0"],na.rm=TRUE), xlab="mean network size for uninfected", main="posterior for mean network size in the uninfected population",sub="infected is dashed")
- lines(density(out[,"mu1"],na.rm=TRUE),lty=2)
- plot(density(out[,"sigma0"],na.rm=TRUE), xlab="s.d. network size", main="posterior for s.d. of the network size for uninfected",sub="infected is dashed")
- lines(density(out[,"sigma1"],na.rm=TRUE),lty=2)
+ graphics::plot(stats::density(out[,"mu0"],na.rm=TRUE), xlab="mean network size for uninfected", main="posterior for mean network size in the uninfected population",sub="infected is dashed")
+ graphics::lines(stats::density(out[,"mu1"],na.rm=TRUE),lty=2)
+ graphics::plot(stats::density(out[,"sigma0"],na.rm=TRUE), xlab="s.d. network size", main="posterior for s.d. of the network size for uninfected",sub="infected is dashed")
+ graphics::lines(stats::density(out[,"sigma1"],na.rm=TRUE),lty=2)
 }
 #
-plot(seq_along(x$predictive.degree),y=x$predictive.degree, type='h',
+graphics::plot(seq_along(x$predictive.degree),y=x$predictive.degree, type='h',
 col='red', lwd=2, xlab="degree",ylab="probability",
   main="mean posterior network size distribution")
 if(!is.null(control$data)){
   Kmax <- max(seq_along(x$predictive.degree))
   bbb <- tabulate(control$data,nbins=Kmax) #, nbins=max(control$data))
   bbb <- bbb/sum(bbb)
-  aaa <- barplot(bbb,names.arg=1:Kmax,add=FALSE,axes=TRUE,width=rep(0.5,length(bbb)),space=1,col=0,
+  aaa <- graphics::barplot(bbb,names.arg=1:Kmax,add=FALSE,axes=TRUE,width=rep(0.5,length(bbb)),space=1,col=0,
     xlab="degree",ylab="probability", xlim=c(1,Kmax),
     main="posterior with sample histogram overlaid")
-  lines(x=-0.25+seq_along(x$predictive.degree),y=x$predictive.degree, type='h', col='red', lwd=2)
+  graphics::lines(x=-0.25+seq_along(x$predictive.degree),y=x$predictive.degree, type='h', col='red', lwd=2)
 }}
 }else{
 if(control$type %in% c("others","both")){
@@ -236,11 +242,11 @@ if(control$type %in% c("others","both")){
   #
   if(is.null(control$xlim)){control$xlim <- xp[which.max(cy>0.99)]}
   if(is.null(control$ylim)){control$ylim <- c(0,max(lpriorm))}
-  plot(x=xp,y=lpriorm,type='l', xlab="population size", 
+  graphics::plot(x=xp,y=lpriorm,type='l', xlab="population size", 
     main="prior for population size",
     ylab="prior density",xlim=c(x$n,control$xlim),ylim=control$ylim)
   #
-  abline(v=x$n,lty=2)
+  sabline(v=x$n,lty=2)
   #
 #
   map <- xp[which.max(lpriorm)]
@@ -249,20 +255,21 @@ if(control$type %in% c("others","both")){
   l50 <- xp[which.max(cy>0.5)]
   hpd <- c(xp[which.max(cy>0.25)],xp[which.max(cy>0.75)])
 #
-  abline(v=l50,col=2)
-  abline(v=mp,col=3)
-  abline(v=c(x$n,x$maxN),lty=2)
-  if(!is.null(control$N)){abline(v=control$N,lty=1,col=1)}
-  abline(v=hpd,lty=2,col=4)
+  sabline(v=l50,col=2)
+  sabline(v=mp,col=3)
+  sabline(v=map,col=5)
+  sabline(v=c(x$n,x$maxN),lty=2)
+  if(!is.null(control$N)){sabline(v=control$N,lty=1,col=1)}
+  sabline(v=hpd,lty=2,col=4)
   yloc <- control$ylim[2]*0.06
-  par(xpd=NA)
-  text(x=hpd[1],y=-yloc,col=4,cex=0.5,labels=paste(round(hpd[1])))
-  text(x=hpd[2],y=-yloc,col=4,cex=0.5,labels=paste(round(hpd[2])))
-  text(x=x$n,y=-0.0,labels=paste(x$n),col=1,cex=1.0)
-  text(x=mp,y=-yloc,col=3,cex=0.5,labels=paste(round(mp)))
-  text(x=l50,y=-yloc,col=2,cex=0.5,labels=paste(round(l50)))
-  text(x=map,y=-yloc,col=5,cex=0.5,labels=paste(round(map)))
-  if(!is.null(control$N)){text(x=control$N,y=-yloc,col=1,cex=0.5,labels="truth")}
+  graphics::par(xpd=NA)
+  graphics::text(x=hpd[1],y=-yloc,col=4,cex=0.5,labels=paste(round(hpd[1])))
+  graphics::text(x=hpd[2],y=-yloc,col=4,cex=0.5,labels=paste(round(hpd[2])))
+  graphics::text(x=x$n,y=-0.0,labels=paste(x$n),col=1,cex=1.0)
+  graphics::text(x=mp,y=-yloc,col=3,cex=0.5,labels=paste(round(mp)))
+  graphics::text(x=l50,y=-yloc,col=2,cex=0.5,labels=paste(round(l50)))
+  graphics::text(x=map,y=-yloc,col=5,cex=0.5,labels=paste(round(map)))
+  if(!is.null(control$N)){graphics::text(x=control$N,y=-yloc,col=1,cex=0.5,labels="truth")}
 }
 #
 #cat(sprintf("Prior:\nMean = %d, Median = %d, Mode = %d, 25%% = %d, 75%% = %d.\n",
